==> lirc-0.9.2a.tar.bz2: api-docs/html/search/all_4.js <==
var searchData=
[
  ['decode_5fall',['decode_all',['../group__driver__api.html#gae334c37e486ce414abf272d4850df6c4',1,'decode_all(struct ir_remote *remotes):&#160;ir_remote.c'],['../group__driver__api.html#gae334c37e486ce414abf272d4850df6c4',1,'decode_all(struct ir_remote *remotes):&#160;ir_remote.c']]],
  ['decode_5fctx_5ft',['decode_ctx_t',['../structdecode__ctx__t.html',1,'']]],
  ['decode_5ffunc',['decode_func',['../structdriver.html#a761099e25fcbf8f0ca9a5b45fbd1f5fc',1,'driver']]],
  ['default_5fclose',['default_close',['../group__driver__api.html#ga683dd53e7e5d62746c1a645fe133daf0',1,'default_close():&#160;driver.c'],['../group__driver__api.html#ga683dd53e7e5d62746c1a645fe133daf0',1,'default_close(void):&#160;driver.c']]],
  ['default_5fdrvctl',['default_drvctl',['../group__driver__api.html#ga96e3243bc45ff488f6c55dde5e9b377b',1,'default_drvctl(unsigned int fd, void *arg):&#160;driver.c'],['../group__driver__api.html#ga96e3243bc45ff488f6c55dde5e9b377b',1,'default_drvctl(unsigned int cmd, void *arg):&#160;driver.c']]],
  ['default_5floglevel',['DEFAULT_LOGLEVEL',['../lirc__log_8h.html#aec8c265923c6714be1f4a42e252bc872',1,'lirc_log.h']]],
  ['default_5fopen',['default_open',['../group__driver__api.html#gac0f7baaef9fe524365c16022001804d3',1,'default_open(const char *path):&#160;driver.c'],['../group__driver__api.html#gac0f7baaef9fe524365c16022001804d3',1,'default_open(const char *path):&#160;driver.c']]],
  ['default_5fpermissions',['DEFAULT_PERMISSIONS',['../lirc__config_8h.html#a47065dcf5a6c3bb4399ff92d52f5f3aa',1,'lirc_config.h']]],
  ['default_5frepeat_5fmax',['DEFAULT_REPEAT_MAX',['../lirc__config_8h.html#a7ff202f4553b9745a9ce558a253e9ba0',1,'lirc_config.h']]],
  ['deinit_5ffunc',['deinit_func',['../structdriver.html#ac1ac9d52e4ef2c7ce3cd05a3536d7875',1,'driver']]],
  ['deprecated_20list',['Deprecated List',['../deprecated.html',1,'']]],
  ['dev_5flircd',['DEV_LIRCD',['../lirc__config_8h.html#a751f0443b7ed334e94d0e50358bc266f',1,'lirc_config.h']]],
  ['dev_5flircm',['DEV_LIRCM',['../lirc__config_8h.html#a4adc1d49358a976a816db0a192755c70',1,'lirc_config.h']]],
  ['device',['device',['../structdriver.html#aca3bbacc48c5f27dac5568bd658afec8',1,'driver']]],
  ['dict_5finvalid_5fkey',['DICT_INVALID_KEY',['../group__ciniparser.html#ga220dbd9af990c8faebfd01bd62b2dde4',1,'dictionary.c']]],
  ['dictionary',['dictionary',['../group__ciniparser.html#ga5bd3b2ce42b776c76755ec65642f43af',1,'dictionary.h']]],
  ['dictionary_2ec',['dictionary.c',['../dictionary_8c.html',1,'']]],
  ['dictionary_2eh',['dictionary.h',['../dictionary_8h.html',1,'']]],
  ['dictionary_5fdel',['dictionary_del',['../group__ciniparser.html#ga9d792f2544cf674a371663e2f32128fa',1,'dictionary.c']]],
  ['dictionary_5fdump',['dictionary_dump',['../group__ciniparser.html#ga6e29ecf9c79331b1c6c26cd662cba042',1,'dictionary.c']]],
  ['dictionary_5fget',['dictionary_get',['../group__ciniparser.html#ga9b891a858ce598f8c87e3312d47bb2fc',1,'dictionary.c']]],
  ['dictionary_5fhash',['dictionary_hash',['../group__ciniparser.html#ga7c1ef0a729e668d1e8d6a7e774feaf2e',1,'dictionary.c']]],
  ['dictionary_5fnew',['dictionary_new',['../group__ciniparser.html#ga876a908eb786f957f939a08a362e514d',1,'dictionary.c']]],
  ['dictionary_5fset',['dictionary_set',['../group__ciniparser.html#gaab65a95ad09062716b24a129d8529b76',1,'dictionary.c']]],
  ['dictionary_5funset',['dictionary_unset',['../group__ciniparser.html#ga27f0752948d52ccd2568dae22f5db2bc',1,'dictionary.c']]],
  ['dictminsz',['DICTMINSZ',['../group__ciniparser.html#gaaf4ab97b3163920286cb932a3faedf86',1,'dictionary.c']]],
  ['driver',['driver',['../structdriver.html',1,'driver'],['../structir__remote.html#a00db6cb8c77235b3f30ea9cdae6239aa',1,'ir_remote::driver()']]],
  ['driver_2ec',['driver.c',['../driver_8c.html',1,'']]],
  ['driver_2eh',['driver.h',['../driver_8h.html',1,'']]],
  ['driver_20api_20manual_20excerpt',['Driver API manual excerpt',['../group__driver__manual.html',1,'']]],
  ['driver_5fversion',['driver_version',['../structdriver.html#a2c48ed8680d2f242dd0c018f846551b7',1,'driver']]],
  ['drv',['drv',['../driver_8c.html#a18548a9bde23bdaa38bd8be5ab24428f',1,'drv():&#160;driver.c'],['../drv__admin_8c.html#a18548a9bde23bdaa38bd8be5ab24428f',1,'drv():&#160;driver.c']]],
  ['drv_5fadmin_2ec',['drv_admin.c',['../drv__admin_8c.html',1,'']]],
  ['drv_5fadmin_2eh',['drv_admin.h',['../drv__admin_8h.html',1,'']]],
  ['drv_5ferr_5fbad_5foption',['DRV_ERR_BAD_OPTION',['../group__driver__api.html#gae98bd204d31330f5e862817faadf7f85',1,'driver.h']]],
  ['drv_5ferr_5fbad_5fstate',['DRV_ERR_BAD_STATE',['../group__driver__api.html#gae323c069918a6b718b3bafd6abbef2a2',1,'driver.h']]],
  ['drv_5ferr_5fnot_5fimplemented',['DRV_ERR_NOT_IMPLEMENTED',['../group__driver__api.html#gab58e0aa64a0fc3769c30e60aaf7061e9',1,'DRV_ERR_NOT_IMPLEMENTED():&#160;driver.h'],['../group__driver__api.html#gab58e0aa64a0fc3769c30e60aaf7061e9',1,'DRV_ERR_NOT_IMPLEMENTED():&#160;driver.h']]],
  ['drv_5fguest_5ffunc',['drv_guest_func',['../drv__admin_8h.html#ab2d7f4aa35dfb02d7f2eaadadd039755',1,'drv_admin.h']]],
  ['drv_5fhandle_5foptions',['drv_handle_options',['../group__driver__api.html#gaae1b223d2bd3a0d0be6e77019c9a976c',1,'drv_handle_options(const char *options):&#160;driver.c'],['../group__driver__api.html#gaae1b223d2bd3a0d0be6e77019c9a976c',1,'drv_handle_options(const char *options):&#160;driver.c']]],
  ['drv_5fnull',['drv_null',['../drv__admin_8c.html#a4812505d2b58c85f504503c9cbc3ef45',1,'drv_admin.c']]],
  ['drvctl_5ffunc',['drvctl_func',['../structdriver.html#a84ea3e16dbac1e5cf03d202f6a68a265',1,'driver']]],
  ['drvctl_5fget_5fstate',['DRVCTL_GET_STATE',['../group__driver__api.html#ga3637dcda1fb5508e6f51a39b0cc048a7',1,'driver.h']]],
  ['drvctl_5fmax',['DRVCTL_MAX',['../group__driver__api.html#ga2628a2556297a773cddc0848db200d1a',1,'driver.h']]],
  ['drvctl_5fsend_5fspace',['DRVCTL_SEND_SPACE',['../group__driver__api.html#ga2d4b7ac43bc60cf3d930431f79b2fb89',1,'driver.h']]],
  ['drvctl_5fset_5foption',['DRVCTL_SET_OPTION',['../group__driver__api.html#ga1033feec74cbc16e939d713be2c5b8e0',1,'driver.h']]],
  ['dump_5fconfig_2ec',['dump_config.c',['../dump__config_8c.html',1,'']]],
  ['dump_5fconfig_2eh',['dump_config.h',['../dump__config_8h.html',1,'']]],
  ['duty_5fcycle',['duty_cycle',['../structir__remote.html#a3edd8099b0f26ca703b051479329446a',1,'ir_remote']]],
  ['dyncode',['dyncode',['../structir__remote.html#ae8172a416ed4f0481f61aaee32b3803c',1,'ir_remote']]],
  ['dyncodes',['dyncodes',['../structir__remote.html#a250d88b2da87c39fc420714afc93c7f6',1,'ir_remote']]],
  ['dyncodes_5fname',['dyncodes_name',['../structir__remote.html#ac41de5381ae0049f897137be727572be',1,'ir_remote']]]
];

==> lirc-0.9.3a.tar.bz2: api-docs/html/search/all_4.js <==
var searchData=
[
  ['decode_5fall',['decode_all',['../group__driver__api.html#gae334c37e486ce414abf272d4850df6c4',1,'decode_all(struct ir_remote *remotes):&#160;ir_remote.c'],['../group__driver__api.html#gae334c37e486ce414abf272d4850df6c4',1,'decode_all(struct ir_remote *remotes):&#160;ir_remote.c']]],
  ['decode_5fctx_5ft',['decode_ctx_t',['../structdecode__ctx__t.html',1,'']]],
  ['decode_5ffunc',['decode_func',['../structdriver.html#a4c8fb1671a48fb248bc8dafa90cded15',1,'driver']]],
  ['default_5fclose',['default_close',['../group__driver__api.html#ga683dd53e7e5d62746c1a645fe133daf0',1,'default_close(void):&#160;driver.c'],['../group__driver__api.html#ga683dd53e7e5d62746c1a645fe133daf0',1,'default_close(void):&#160;driver.c']]],
  ['default_5fdrvctl',['default_drvctl',['../group__driver__api.html#ga96e3243bc45ff488f6c55dde5e9b377b',1,'default_drvctl(unsigned int fd, void *arg):&#160;driver.c'],['../group__driver__api.html#ga96e3243bc45ff488f6c55dde5e9b377b',1,'default_drvctl(unsigned int cmd, void *arg):&#160;driver.c']]],
  ['default_5floglevel',['DEFAULT_LOGLEVEL',['../lirc__log_8h.html#aec8c265923c6714be1f4a42e252bc872',1,'lirc_log.h']]],
  ['default_5fopen',['default_open',['../group__driver__api.html#gac0f7baaef9fe524365c16022001804d3',1,'default_open(const char *path):&#160;driver.c'],['../group__driver__api.html#gac0f7baaef9fe524365c16022001804d3',1,'default_open(const char *path):&#160;driver.c']]],
  ['default_5fpermissions',['DEFAULT_PERMISSIONS',['../lirc__config_8h.html#a47065dcf5a6c3bb4399ff92d52f5f3aa',1,'lirc_config.h']]],
  ['default_5frepeat_5fmax',['DEFAULT_REPEAT_MAX',['../lirc__config_8h.html#a7ff202f4553b9745a9ce558a253e9ba0',1,'lirc_config.h']]],
  ['deinit_5ffunc',['deinit_func',['../structdriver.html#a87fb83240c2426874349f860fb8504dc',1,'driver']]],
  ['deprecated_20list',['Deprecated List',['../deprecated.html',1,'']]],
  ['dev_5flircd',['DEV_LIRCD',['../lirc__config_8h.html#a751f0443b7ed334e94d0e50358bc266f',1,'lirc_config.h']]],
  ['dev_5flircm',['DEV_LIRCM',['../lirc__config_8h.html#a4adc1d49358a976a816db0a192755c70',1,'lirc_config.h']]],
  ['device',['device',['../structdriver.html#aca3bbacc48c5f27dac5568bd658afec8',1,'driver']]],
  ['dict_5finvalid_5fkey',['DICT_INVALID_KEY',['../group__ciniparser.html#ga220dbd9af990c8faebfd01bd62b2dde4',1,'dictionary.c']]],
  ['dictionary',['dictionary',['../group__ciniparser.html#ga5bd3b2ce42b776c76755ec65642f43af',1,'dictionary.h']]],
  ['dictionary_2ec',['dictionary.c',['../dictionary_8c.html',1,'']]],
  ['dictionary_2eh',['dictionary.h',['../dictionary_8h.html',1,'']]],
  ['dictionary_5fdel',['dictionary_del',['../group__ciniparser.html#ga9d792f2544cf674a371663e2f32128fa',1,'dictionary.c']]],
  ['dictionary_5fdump',['dictionary_dump',['../group__ciniparser.html#ga6e29ecf9c79331b1c6c26cd662cba042',1,'dictionary.c']]],
  ['dictionary_5fget',['dictionary_get',['../group__ciniparser.html#ga9b891a858ce598f8c87e3312d47bb2fc',1,'dictionary.c']]],
  ['dictionary_5fhash',['dictionary_hash',['../group__ciniparser.html#ga7c1ef0a729e668d1e8d6a7e774feaf2e',1,'dictionary.c']]],
  ['dictionary_5fnew',['dictionary_new',['../group__ciniparser.html#ga876a908eb786f957f939a08a362e514d',1,'dictionary.c']]],
  ['dictionary_5fset',['dictionary_set',['../group__ciniparser.html#gaab65a95ad09062716b24a129d8529b76',1,'dictionary.c']]],
  ['dictionary_5funset',['dictionary_unset',['../group__ciniparser.html#ga27f0752948d52ccd2568dae22f5db2bc',1,'dictionary.c']]],
  ['dictminsz',['DICTMINSZ',['../group__ciniparser.html#gaaf4ab97b3163920286cb932a3faedf86',1,'dictionary.c']]],
  ['driver',['driver',['../structdriver.html',1,'driver'],['../structir__remote.html#a00db6cb8c77235b3f30ea9cdae6239aa',1,'ir_remote::driver()']]],
  ['driver_2ec',['driver.c',['../driver_8c.html',1,'']]],
  ['driver_2eh',['driver.h',['../driver_8h.html',1,'']]],
  ['driver_20api_20manual_20excerpt',['Driver API manual excerpt',['../group__driver__manual.html',1,'']]],
  ['driver_5fversion',['driver_version',['../structdriver.html#a2c48ed8680d2f242dd0c018f846551b7',1,'driver']]],
  ['drop_5froot_5fcli',['drop_root_cli',['../group__private__api.html#ga24f983a41e2fccf1c7ba3ee4d69559a4',1,'drop_root_cli(int(*set_some_uid)(uid_t)):&#160;util.c'],['../group__private__api.html#ga24f983a41e2fccf1c7ba3ee4d69559a4',1,'drop_root_cli(int(*set_some_uid)(uid_t)):&#160;util.c']]],
  ['drop_5fsudo_5froot',['drop_sudo_root',['../group__private__api.html#ga08cad0a0a22fb34e70ef33be007e484d',1,'drop_sudo_root(int(*set_some_uid)(uid_t)):&#160;util.c'],['../group__private__api.html#ga08cad0a0a22fb34e70ef33be007e484d',1,'drop_sudo_root(int(*set_some_uid)(uid_t)):&#160;util.c']]],
  ['drv',['drv',['../driver_8c.html#a18548a9bde23bdaa38bd8be5ab24428f',1,'drv():&#160;driver.c'],['../drv__admin_8c.html#a18548a9bde23bdaa38bd8be5ab24428f',1,'drv():&#160;driver.c']]],
  ['drv_5fadmin_2ec',['drv_admin.c',['../drv__admin_8c.html',1,'']]],
  ['drv_5fadmin_2eh',['drv_admin.h',['../drv__admin_8h.html',1,'']]],
  ['drv_5ferr_5fbad_5foption',['DRV_ERR_BAD_OPTION',['../group__driver__api.html#gae98bd204d31330f5e862817faadf7f85',1,'driver.h']]],
  ['drv_5ferr_5fbad_5fstate',['DRV_ERR_BAD_STATE',['../group__driver__api.html#gae323c069918a6b718b3bafd6abbef2a2',1,'driver.h']]],
  ['drv_5ferr_5fbad_5fvalue',['DRV_ERR_BAD_VALUE',['../group__driver__api.html#ga548694fee71123534ede5e27aa4e7e1f',1,'driver.h']]],
  ['drv_5ferr_5fnot_5fimplemented',['DRV_ERR_NOT_IMPLEMENTED',['../group__driver__api.html#gab58e0aa64a0fc3769c30e60aaf7061e9',1,'DRV_ERR_NOT_IMPLEMENTED():&#160;driver.h'],['../group__driver__api.html#gab58e0aa64a0fc3769c30e60aaf7061e9',1,'DRV_ERR_NOT_IMPLEMENTED():&#160;driver.h']]],
  ['drv_5fguest_5ffunc',['drv_guest_func',['../drv__admin_8h.html#a66ecd0448214de7b954a4c0307fc1e4b',1,'drv_admin.h']]],
  ['drv_5fhandle_5foptions',['drv_handle_options',['../group__driver__api.html#gaae1b223d2bd3a0d0be6e77019c9a976c',1,'drv_handle_options(const char *options):&#160;driver.c'],['../group__driver__api.html#gaae1b223d2bd3a0d0be6e77019c9a976c',1,'drv_handle_options(const char *options):&#160;driver.c']]],
  ['drv_5fnull',['drv_null',['../drv__admin_8c.html#a4812505d2b58c85f504503c9cbc3ef45',1,'drv_admin.c']]],
  ['drvctl_5ffunc',['drvctl_func',['../structdriver.html#ac5d035961037ecb0a74182dd456ced26',1,'driver']]],
  ['drvctl_5fget_5fstate',['DRVCTL_GET_STATE',['../group__driver__api.html#ga3637dcda1fb5508e6f51a39b0cc048a7',1,'driver.h']]],
  ['drvctl_5fmax',['DRVCTL_MAX',['../group__driver__api.html#ga2628a2556297a773cddc0848db200d1a',1,'driver.h']]],
  ['drvctl_5fsend_5fspace',['DRVCTL_SEND_SPACE',['../group__driver__api.html#ga2d4b7ac43bc60cf3d930431f79b2fb89',1,'driver.h']]],
  ['drvctl_5fset_5foption',['DRVCTL_SET_OPTION',['../group__driver__api.html#ga1033feec74cbc16e939d713be2c5b8e0',1,'driver.h']]],
  ['dump_5fconfig_2ec',['dump_config.c',['../dump__config_8c.html',1,'']]],
  ['dump_5fconfig_2eh',['dump_config.h',['../dump__config_8h.html',1,'']]],
  ['duty_5fcycle',['duty_cycle',['../structir__remote.html#a3edd8099b0f26ca703b051479329446a',1,'ir_remote']]],
  ['dyncode',['dyncode',['../structir__remote.html#ae8172a416ed4f0481f61aaee32b3803c',1,'ir_remote']]],
  ['dyncodes',['dyncodes',['../structir__remote.html#a250d88b2da87c39fc420714afc93c7f6',1,'ir_remote']]],
  ['dyncodes_5fname',['dyncodes_name',['../structir__remote.html#ac41de5381ae0049f897137be727572be',1,'ir_remote']]]
];
